@@ -37,19 +37,20 @@ def test_parse_module():
                 "3.7",
                 "3.8",
                 "3.9",
+                "3.10",
             ],
         ),
-        (">=3.5", ["3", "3.5", "3.6", "3.7", "3.8", "3.9"]),
+        (">=3.5", ["3", "3.5", "3.6", "3.7", "3.8", "3.9", "3.10"]),
         ("<3.8,>=3.5", ["3", "3.5", "3.6", "3.7"]),
         (">=3.6.1,<3.10", ["3", "3.6", "3.7", "3.8", "3.9"]),
         (">=3.6,!=3.8,<3.10", ["3", "3.6", "3.8", "3.7", "3.9"]),  # !=3.8 means !=3.8.0
         (">=3.6,!=3.8.*,<3.10", ["3", "3.6", "3.7", "3.9"]),
-        (">3.8,!=3.9.*", ["3", "3.8"]),
-        (">3.9.1", ["3", "3.9"]),
+        (">3.8,!=3.9.*", ["3", "3.8", "3.10"]),
+        (">3.9.1", ["3", "3.9", "3.10"]),
         (">3.4.10,<3.5", []),  # no versions in 3.4 are larger than 3.4.10
         (">3.9.1,<3.9.1", []),
         (">3.9.1,<3.9.2", []),
-        ("~=3.6", ["3", "3.6", "3.7", "3.8", "3.9"]),
+        ("~=3.6", ["3", "3.6", "3.7", "3.8", "3.9", "3.10"]),
         ("~=3.6.1", ["3", "3.6"]),
         ("==3.6.1", ["3", "3.6"]),
         ("===3.6.1", ["3", "3.6"]),
@@ -144,6 +145,14 @@ def test_project_version_use_scm(project_with_scm):
     assert "0.1.1.dev1+g" in metadata.version
 
 
+def test_project_name_and_version_missing():
+    metadata = Metadata(FIXTURES / "projects/demo-no-name-nor-version/pyproject.toml")
+    assert metadata.version is None
+    assert metadata.name is None
+    assert metadata.project_name is None
+    assert metadata.project_filename == "UNKNOWN"
+
+
 def test_explicit_package_dir():
     metadata = Metadata(FIXTURES / "projects/demo-explicit-package-dir/pyproject.toml")
     paths = metadata.convert_package_paths()
